==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_functions/mp3641_001/MP3641_SyncCaseManagement_001.java <==

package net.datastream.schemas.mp_functions.mp3641_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.casemanagement_001.CaseManagement;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/CaseManagement_001}CaseManagement"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="CaseManagement" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="confirmdeletetask" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *       &lt;attribute name="confirmcasecloseforopenchklst" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "caseManagement"
})
@XmlRootElement(name = "MP3641_SyncCaseManagement_001")
public class MP3641_SyncCaseManagement_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "CaseManagement", namespace = "http://schemas.datastream.net/MP_entities/CaseManagement_001", required = true)
    protected CaseManagement caseManagement;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "confirmdeletetask")
    protected String confirmdeletetask;
    @XmlAttribute(name = "confirmcasecloseforopenchklst")
    protected String confirmcasecloseforopenchklst;

    /**
     * Obtient la valeur de la propriété caseManagement.
     * 
     * @return
     *     possible object is
     *     {@link CaseManagement }
     *     
     */
    public CaseManagement getCaseManagement() {
        return caseManagement;
    }

    /**
     * Définit la valeur de la propriété caseManagement.
     * 
     * @param value
     *     allowed object is
     *     {@link CaseManagement }
     *     
     */
    public void setCaseManagement(CaseManagement value) {
        this.caseManagement = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.CASE_MANAGEMENT;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Obtient la valeur de la propriété confirmdeletetask.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmdeletetask() {
        return confirmdeletetask;
    }

    /**
     * Définit la valeur de la propriété confirmdeletetask.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmdeletetask(String value) {
        this.confirmdeletetask = value;
    }

    /**
     * Obtient la valeur de la propriété confirmcasecloseforopenchklst.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmcasecloseforopenchklst() {
        return confirmcasecloseforopenchklst;
    }

    /**
     * Définit la valeur de la propriété confirmcasecloseforopenchklst.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmcasecloseforopenchklst(String value) {
        this.confirmcasecloseforopenchklst = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_functions/mp3641_001/MP3641_SyncCaseManagement_001.java <==

package net.datastream.schemas.mp_functions.mp3641_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.casemanagement_001.CaseManagement;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/CaseManagement_001}CaseManagement"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="CaseManagement" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="confirmdeletetask" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *       &lt;attribute name="confirmcasecloseforopenchklst" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "caseManagement"
})
@XmlRootElement(name = "MP3641_SyncCaseManagement_001")
public class MP3641_SyncCaseManagement_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "CaseManagement", namespace = "http://schemas.datastream.net/MP_entities/CaseManagement_001", required = true)
    protected CaseManagement caseManagement;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "confirmdeletetask")
    protected String confirmdeletetask;
    @XmlAttribute(name = "confirmcasecloseforopenchklst")
    protected String confirmcasecloseforopenchklst;

    /**
     * Gets the value of the caseManagement property.
     * 
     * @return
     *     possible object is
     *     {@link CaseManagement }
     *     
     */
    public CaseManagement getCaseManagement() {
        return caseManagement;
    }

    /**
     * Sets the value of the caseManagement property.
     * 
     * @param value
     *     allowed object is
     *     {@link CaseManagement }
     *     
     */
    public void setCaseManagement(CaseManagement value) {
        this.caseManagement = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.CASE_MANAGEMENT;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the confirmdeletetask property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmdeletetask() {
        return confirmdeletetask;
    }

    /**
     * Sets the value of the confirmdeletetask property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmdeletetask(String value) {
        this.confirmdeletetask = value;
    }

    /**
     * Gets the value of the confirmcasecloseforopenchklst property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmcasecloseforopenchklst() {
        return confirmcasecloseforopenchklst;
    }

    /**
     * Sets the value of the confirmcasecloseforopenchklst property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmcasecloseforopenchklst(String value) {
        this.confirmcasecloseforopenchklst = value;
    }

}
